@@ -1,6 +1,6 @@
 package Bot::Backbone::Service;
 BEGIN {
-  $Bot::Backbone::Service::VERSION = '0.112320';
+  $Bot::Backbone::Service::VERSION = '0.112400';
 }
 use v5.10;
 use Moose();
@@ -75,7 +75,7 @@ Bot::Backbone::Service - Useful features for services
 
 =head1 VERSION
 
-version 0.112320
+version 0.112400
 
 =head1 SYNOPSIS
 
@@ -83,9 +83,17 @@ version 0.112320
   use v5.14; # because newer Perl is cooler than older Perl
   use Bot::Backbone::Service;
 
-  with 'Bot::Backbone::Service::Role::Service';
+  with qw(
+      Bot::Backbone::Service::Role::Service
+      Bot::Backbone::Service::Role::Responder
+  );
 
-  dispatch as {
+  # Instead of Bot::Backbone::Service::Role::Responder, you may prefer to
+  # apply the Bot::Backbone::Service::Role::ChatConsumer role instead. It
+  # really depends on if this module will be used across multiple chats or
+  # needs to be tied to a specific chat.
+
+  service_dispatcher as {
       command '!echo' => given_parameters {
           parameter thing => ( match => qr/.+/ );
       } respond_by_method 'echo_back';
