@@ -1,6 +1,6 @@
 package Bot::Backbone::Service::DirectChat;
 BEGIN {
-  $Bot::Backbone::Service::DirectChat::VERSION = '0.112320';
+  $Bot::Backbone::Service::DirectChat::VERSION = '0.112400';
 }
 use v5.10;
 use Moose;
@@ -8,43 +8,41 @@ use Moose;
 with qw(
     Bot::Backbone::Service::Role::Service
     Bot::Backbone::Service::Role::Dispatch
-    Bot::Backbone::Service::Role::Chat
     Bot::Backbone::Service::Role::ChatConsumer
 );
 
+with 'Bot::Backbone::Service::Role::Chat' => {
+    -excludes => [ qw( send_message ) ],
+};
+
 # ABSTRACT: A helper for doing direct chats
 
 
 sub initialize { }
 
 
-sub send_reply {
-    my ($self, $message, $text) = @_;
-    $self->chat->send_reply($message, $text);
-}
-
-
 sub send_message {
-    my ($self, %params) = @_;
+    my ($self, $params) = @_;
 
-    my $to = $params{to} // Bot::Backbone::Identity->new(
-        username => $params{to_username},
-        (defined $params{to_nickname} ? (nickname => $params{to_nickname}) : ()),
+    my $to = $params->{to} // Bot::Backbone::Identity->new(
+        username => $params->{to_username},
+        (defined $params->{to_nickname} ? (nickname => $params->{to_nickname}) : ()),
     );
 
-    my $text = $params{text};
+    my $text = $params->{text};
 
-    $self->chat->send_message(
+    $self->chat->send_message({
         to   => $to,
         text => $text,
-    );
+    });
 }
 
 
 sub receive_message {
     my ($self, $message) = @_;
 
-    return unless $message->is_direct;
+    return unless not $message->is_group
+                  and $message->is_direct;
 
     $self->resend_message($message);
     $self->dispatch_message($message);
@@ -61,7 +59,7 @@ Bot::Backbone::Service::DirectChat - A helper for doing direct chats
 
 =head1 VERSION
 
-version 0.112320
+version 0.112400
 
 =head1 SYNOPSIS
 
@@ -81,18 +79,14 @@ passes on direct chats received and only sends direct chages back.
 
 Does nothing.
 
-=head2 send_reply
-
-Forwards the direct message reply on to the nested chat service.
-
 =head2 send_message
 
 Sends a direct message chat to the nested chat service.
 
 =head2 receive_message
 
-If the message is direct, it will be passed on to any chat consumers and
-dispatched.
+If the message is not to a group and is sent direct, it will be passed on to
+any chat consumers and dispatched.
 
 =head1 AUTHOR
 
