@@ -1,10 +1,12 @@
 package Bot::Backbone::Service::Role::ChatConsumer;
 BEGIN {
-  $Bot::Backbone::Service::Role::ChatConsumer::VERSION = '0.112320';
+  $Bot::Backbone::Service::Role::ChatConsumer::VERSION = '0.112400';
 }
 use v5.10;
 use Moose::Role;
 
+with 'Bot::Backbone::Service::Role::SendPolicy';
+
 # ABSTRACT: Role for services that listen for chat messages
 
 
@@ -28,6 +30,11 @@ has chat => (
     predicate   => 'has_setup_the_chat',
 );
 
+# XXX Don't delegate these two. Delegation and -excludes don't seem to
+# cooperate very well.
+sub send_message { shift->chat->send_message(@_) }
+sub send_reply   { shift->chat->send_reply(@_) }
+
 sub _build_chat {
     my $self = shift;
     my $chat = $self->bot->services->{ $self->chat_name };
@@ -59,7 +66,7 @@ Bot::Backbone::Service::Role::ChatConsumer - Role for services that listen for c
 
 =head1 VERSION
 
-version 0.112320
+version 0.112400
 
 =head1 DESCRIPTION
 
@@ -100,6 +107,12 @@ ignored.
 
 =head1 METHODS
 
+=head2 send_message
+
+=head2 send_reply
+
+Be sure to use these versions of the methods. Otherwise any send policies you have set on this class will be ignored.
+
 =head2 initialize
 
 This adds a bit of code to run before the service's C</initialize>. It loads
